#!/bin/bash

set -e

ARMV7="armv7-unknown-linux-gnueabihf"

if [ -z "${BIN_NAME}" ]; then
    echo "Missing BIN_NAME, exiting" >&2
    exit 1
fi

if [ -z "${BIN_VERSION}" ]; then
    echo "Missing BIN_VERSION, exiting" >&2
    exit 1
fi


source ${HOME}/.cargo/env

cat >>"${HOME}/.cargo/config" <<EOF
[build]
rustflags = ["-C", "strip=symbols"]

[target."${ARMV7}"]
linker = "arm-linux-gnueabihf-gcc"

EOF

PROJ_DIR="${BIN_NAME}-${BIN_VERSION}"
CRATE="${PROJ_DIR}.crate"

if [ ! -f "${CRATE}" ]; then
    echo "Expected crate not found" >&2
    exit 1
fi

tar xf "${CRATE}"

cd "${PROJ_DIR}"

cargo build --release --target "${ARMV7}"
BIN_PATH="target/${ARMV7}/release/${BIN_NAME}"
mv "${BIN_PATH}" "/opt/build/${ARMV7}_${BIN_NAME}"

cd /opt/build

rm -rf "${PROJ_DIR}"
